@@ -23,61 +23,70 @@ from aliyunsdkpolardb.endpoint import endpoint_data
 class CreateParameterGroupRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'polardb', '2017-08-01', 'CreateParameterGroup')
+		RpcRequest.__init__(self, 'polardb', '2017-08-01', 'CreateParameterGroup','polardb')
 		self.set_method('POST')
-
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_ResourceOwnerId(self): # Long
+
+	def get_ResourceOwnerId(self):
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
-		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
-	def get_ResourceGroupId(self): # String
+	def set_ResourceOwnerId(self,ResourceOwnerId):
+		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
+
+	def get_ResourceGroupId(self):
 		return self.get_query_params().get('ResourceGroupId')
 
-	def set_ResourceGroupId(self, ResourceGroupId):  # String
-		self.add_query_param('ResourceGroupId', ResourceGroupId)
-	def get_ResourceOwnerAccount(self): # String
+	def set_ResourceGroupId(self,ResourceGroupId):
+		self.add_query_param('ResourceGroupId',ResourceGroupId)
+
+	def get_ResourceOwnerAccount(self):
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
-		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
-	def get_OwnerAccount(self): # String
+	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
+		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
+
+	def get_OwnerAccount(self):
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self, OwnerAccount):  # String
-		self.add_query_param('OwnerAccount', OwnerAccount)
-	def get_OwnerId(self): # Long
+	def set_OwnerAccount(self,OwnerAccount):
+		self.add_query_param('OwnerAccount',OwnerAccount)
+
+	def get_OwnerId(self):
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
-	def get_DBType(self): # String
+	def set_OwnerId(self,OwnerId):
+		self.add_query_param('OwnerId',OwnerId)
+
+	def get_DBType(self):
 		return self.get_query_params().get('DBType')
 
-	def set_DBType(self, DBType):  # String
-		self.add_query_param('DBType', DBType)
-	def get_DBVersion(self): # String
+	def set_DBType(self,DBType):
+		self.add_query_param('DBType',DBType)
+
+	def get_DBVersion(self):
 		return self.get_query_params().get('DBVersion')
 
-	def set_DBVersion(self, DBVersion):  # String
-		self.add_query_param('DBVersion', DBVersion)
-	def get_ParameterGroupName(self): # String
+	def set_DBVersion(self,DBVersion):
+		self.add_query_param('DBVersion',DBVersion)
+
+	def get_ParameterGroupName(self):
 		return self.get_query_params().get('ParameterGroupName')
 
-	def set_ParameterGroupName(self, ParameterGroupName):  # String
-		self.add_query_param('ParameterGroupName', ParameterGroupName)
-	def get_Parameters(self): # String
+	def set_ParameterGroupName(self,ParameterGroupName):
+		self.add_query_param('ParameterGroupName',ParameterGroupName)
+
+	def get_Parameters(self):
 		return self.get_query_params().get('Parameters')
 
-	def set_Parameters(self, Parameters):  # String
-		self.add_query_param('Parameters', Parameters)
-	def get_ParameterGroupDesc(self): # String
+	def set_Parameters(self,Parameters):
+		self.add_query_param('Parameters',Parameters)
+
+	def get_ParameterGroupDesc(self):
 		return self.get_query_params().get('ParameterGroupDesc')
 
-	def set_ParameterGroupDesc(self, ParameterGroupDesc):  # String
-		self.add_query_param('ParameterGroupDesc', ParameterGroupDesc)
+	def set_ParameterGroupDesc(self,ParameterGroupDesc):
+		self.add_query_param('ParameterGroupDesc',ParameterGroupDesc)
\ No newline at end of file
