@@ -23,66 +23,76 @@ from aliyunsdkpolardb.endpoint import endpoint_data
 class ModifyDBNodesParametersRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'polardb', '2017-08-01', 'ModifyDBNodesParameters')
+		RpcRequest.__init__(self, 'polardb', '2017-08-01', 'ModifyDBNodesParameters','polardb')
 		self.set_method('POST')
-
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_ResourceOwnerId(self): # Long
+
+	def get_ResourceOwnerId(self):
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
-		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
-	def get_PlannedEndTime(self): # String
+	def set_ResourceOwnerId(self,ResourceOwnerId):
+		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
+
+	def get_PlannedEndTime(self):
 		return self.get_query_params().get('PlannedEndTime')
 
-	def set_PlannedEndTime(self, PlannedEndTime):  # String
-		self.add_query_param('PlannedEndTime', PlannedEndTime)
-	def get_DBNodeIds(self): # String
+	def set_PlannedEndTime(self,PlannedEndTime):
+		self.add_query_param('PlannedEndTime',PlannedEndTime)
+
+	def get_DBNodeIds(self):
 		return self.get_query_params().get('DBNodeIds')
 
-	def set_DBNodeIds(self, DBNodeIds):  # String
-		self.add_query_param('DBNodeIds', DBNodeIds)
-	def get_ParameterGroupId(self): # String
+	def set_DBNodeIds(self,DBNodeIds):
+		self.add_query_param('DBNodeIds',DBNodeIds)
+
+	def get_ParameterGroupId(self):
 		return self.get_query_params().get('ParameterGroupId')
 
-	def set_ParameterGroupId(self, ParameterGroupId):  # String
-		self.add_query_param('ParameterGroupId', ParameterGroupId)
-	def get_ResourceOwnerAccount(self): # String
+	def set_ParameterGroupId(self,ParameterGroupId):
+		self.add_query_param('ParameterGroupId',ParameterGroupId)
+
+	def get_ResourceOwnerAccount(self):
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
-		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
-	def get_DBClusterId(self): # String
+	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
+		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
+
+	def get_DBClusterId(self):
 		return self.get_query_params().get('DBClusterId')
 
-	def set_DBClusterId(self, DBClusterId):  # String
-		self.add_query_param('DBClusterId', DBClusterId)
-	def get_OwnerAccount(self): # String
+	def set_DBClusterId(self,DBClusterId):
+		self.add_query_param('DBClusterId',DBClusterId)
+
+	def get_OwnerAccount(self):
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self, OwnerAccount):  # String
-		self.add_query_param('OwnerAccount', OwnerAccount)
-	def get_OwnerId(self): # Long
+	def set_OwnerAccount(self,OwnerAccount):
+		self.add_query_param('OwnerAccount',OwnerAccount)
+
+	def get_OwnerId(self):
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
-	def get_PlannedStartTime(self): # String
+	def set_OwnerId(self,OwnerId):
+		self.add_query_param('OwnerId',OwnerId)
+
+	def get_PlannedStartTime(self):
 		return self.get_query_params().get('PlannedStartTime')
 
-	def set_PlannedStartTime(self, PlannedStartTime):  # String
-		self.add_query_param('PlannedStartTime', PlannedStartTime)
-	def get_Parameters(self): # String
+	def set_PlannedStartTime(self,PlannedStartTime):
+		self.add_query_param('PlannedStartTime',PlannedStartTime)
+
+	def get_Parameters(self):
 		return self.get_query_params().get('Parameters')
 
-	def set_Parameters(self, Parameters):  # String
-		self.add_query_param('Parameters', Parameters)
-	def get_FromTimeService(self): # Boolean
+	def set_Parameters(self,Parameters):
+		self.add_query_param('Parameters',Parameters)
+
+	def get_FromTimeService(self):
 		return self.get_query_params().get('FromTimeService')
 
-	def set_FromTimeService(self, FromTimeService):  # Boolean
-		self.add_query_param('FromTimeService', FromTimeService)
+	def set_FromTimeService(self,FromTimeService):
+		self.add_query_param('FromTimeService',FromTimeService)
\ No newline at end of file
