@@ -23,51 +23,58 @@ from aliyunsdkpolardb.endpoint import endpoint_data
 class ModifyLogBackupPolicyRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'polardb', '2017-08-01', 'ModifyLogBackupPolicy')
+		RpcRequest.__init__(self, 'polardb', '2017-08-01', 'ModifyLogBackupPolicy','polardb')
 		self.set_method('POST')
-
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_ResourceOwnerId(self): # Long
+
+	def get_ResourceOwnerId(self):
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
-		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
-	def get_LogBackupAnotherRegionRegion(self): # String
+	def set_ResourceOwnerId(self,ResourceOwnerId):
+		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
+
+	def get_LogBackupAnotherRegionRegion(self):
 		return self.get_query_params().get('LogBackupAnotherRegionRegion')
 
-	def set_LogBackupAnotherRegionRegion(self, LogBackupAnotherRegionRegion):  # String
-		self.add_query_param('LogBackupAnotherRegionRegion', LogBackupAnotherRegionRegion)
-	def get_ResourceOwnerAccount(self): # String
+	def set_LogBackupAnotherRegionRegion(self,LogBackupAnotherRegionRegion):
+		self.add_query_param('LogBackupAnotherRegionRegion',LogBackupAnotherRegionRegion)
+
+	def get_ResourceOwnerAccount(self):
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
-		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
-	def get_DBClusterId(self): # String
+	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
+		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
+
+	def get_DBClusterId(self):
 		return self.get_query_params().get('DBClusterId')
 
-	def set_DBClusterId(self, DBClusterId):  # String
-		self.add_query_param('DBClusterId', DBClusterId)
-	def get_OwnerAccount(self): # String
+	def set_DBClusterId(self,DBClusterId):
+		self.add_query_param('DBClusterId',DBClusterId)
+
+	def get_OwnerAccount(self):
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self, OwnerAccount):  # String
-		self.add_query_param('OwnerAccount', OwnerAccount)
-	def get_OwnerId(self): # Long
+	def set_OwnerAccount(self,OwnerAccount):
+		self.add_query_param('OwnerAccount',OwnerAccount)
+
+	def get_OwnerId(self):
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
-	def get_LogBackupAnotherRegionRetentionPeriod(self): # String
+	def set_OwnerId(self,OwnerId):
+		self.add_query_param('OwnerId',OwnerId)
+
+	def get_LogBackupAnotherRegionRetentionPeriod(self):
 		return self.get_query_params().get('LogBackupAnotherRegionRetentionPeriod')
 
-	def set_LogBackupAnotherRegionRetentionPeriod(self, LogBackupAnotherRegionRetentionPeriod):  # String
-		self.add_query_param('LogBackupAnotherRegionRetentionPeriod', LogBackupAnotherRegionRetentionPeriod)
-	def get_LogBackupRetentionPeriod(self): # String
+	def set_LogBackupAnotherRegionRetentionPeriod(self,LogBackupAnotherRegionRetentionPeriod):
+		self.add_query_param('LogBackupAnotherRegionRetentionPeriod',LogBackupAnotherRegionRetentionPeriod)
+
+	def get_LogBackupRetentionPeriod(self):
 		return self.get_query_params().get('LogBackupRetentionPeriod')
 
-	def set_LogBackupRetentionPeriod(self, LogBackupRetentionPeriod):  # String
-		self.add_query_param('LogBackupRetentionPeriod', LogBackupRetentionPeriod)
+	def set_LogBackupRetentionPeriod(self,LogBackupRetentionPeriod):
+		self.add_query_param('LogBackupRetentionPeriod',LogBackupRetentionPeriod)
\ No newline at end of file
